summaryrefslogtreecommitdiff
path: root/sw/source/core/text/porfld.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/text/porfld.cxx')
-rw-r--r--sw/source/core/text/porfld.cxx46
1 files changed, 23 insertions, 23 deletions
diff --git a/sw/source/core/text/porfld.cxx b/sw/source/core/text/porfld.cxx
index 3f40a3384879..d28a18be387c 100644
--- a/sw/source/core/text/porfld.cxx
+++ b/sw/source/core/text/porfld.cxx
@@ -511,7 +511,7 @@ SwNumberPortion::SwNumberPortion( const OUString &rExpand,
SetCenter( bCntr );
}
-sal_Int32 SwNumberPortion::GetCrsrOfst( const sal_uInt16 ) const
+sal_Int32 SwNumberPortion::GetCursorOfst( const sal_uInt16 ) const
{
return 0;
}
@@ -549,12 +549,12 @@ bool SwNumberPortion::Format( SwTextFormatInfo &rInf )
if ( !mbLabelAlignmentPosAndSpaceModeActive )
{
- if ( !rInf.GetTextFrm()->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING) &&
+ if ( !rInf.GetTextFrame()->GetTextNode()->getIDocumentSettingAccess()->get(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING) &&
// #i32902#
!IsFootnoteNumPortion() )
{
nDiff = rInf.Left()
- + rInf.GetTextFrm()->GetTextNode()->
+ + rInf.GetTextFrame()->GetTextNode()->
GetSwAttrSet().GetLRSpace().GetTextFirstLineOfst()
- rInf.First()
+ rInf.ForcedLeftMargin();
@@ -577,7 +577,7 @@ bool SwNumberPortion::Format( SwTextFormatInfo &rInf )
nDiff = nFixWidth + nMinDist;
// Numbering evades the Fly, no nDiff in the second round
// Tricky special case: FlyFrm is in an Area we're just about to
// acquire
// The NumberPortion is marked as hidden
const bool bFly = rInf.GetFly() ||
@@ -687,8 +687,8 @@ void SwNumberPortion::Paint( const SwTextPaintInfo &rInf ) const
sal_uInt16 nSpaceOffs = nFixWidth;
pThis->Width( nFixWidth );
- if( ( IsLeft() && ! rInf.GetTextFrm()->IsRightToLeft() ) ||
- ( ! IsLeft() && ! IsCenter() && rInf.GetTextFrm()->IsRightToLeft() ) )
+ if( ( IsLeft() && ! rInf.GetTextFrame()->IsRightToLeft() ) ||
+ ( ! IsLeft() && ! IsCenter() && rInf.GetTextFrame()->IsRightToLeft() ) )
SwExpandPortion::Paint( rInf );
else
{
@@ -753,7 +753,7 @@ SwBulletPortion::SwBulletPortion( const sal_Unicode cBullet,
#define GRFNUM_SECURE 10
SwGrfNumPortion::SwGrfNumPortion(
- SwFrm*,
+ SwFrame*,
const OUString& rGraphicFollowedBy,
const SvxBrushItem* pGrfBrush,
const SwFormatVertOrient* pGrfOrient, const Size& rGrfSize,
@@ -858,7 +858,7 @@ bool SwGrfNumPortion::Format( SwTextFormatInfo &rInf )
nDiff = nFixWidth + nMinDist;
// Numbering evades Fly, no nDiff in the second round
// Tricky special case: FlyFrm is in the Area we were just
// about to get a hold of.
// The NumberPortion is marked as hidden
if( nDiff > rInf.Width() )
@@ -895,8 +895,8 @@ void SwGrfNumPortion::Paint( const SwTextPaintInfo &rInf ) const
Size aSize( nTmpWidth, GetGrfHeight() - 2 * GRFNUM_SECURE );
const bool bTmpLeft = mbLabelAlignmentPosAndSpaceModeActive ||
- ( IsLeft() && ! rInf.GetTextFrm()->IsRightToLeft() ) ||
- ( ! IsLeft() && ! IsCenter() && rInf.GetTextFrm()->IsRightToLeft() );
+ ( IsLeft() && ! rInf.GetTextFrame()->IsRightToLeft() ) ||
+ ( ! IsLeft() && ! IsCenter() && rInf.GetTextFrame()->IsRightToLeft() );
if( nFixWidth < Width() && !bTmpLeft )
{
@@ -932,8 +932,8 @@ void SwGrfNumPortion::Paint( const SwTextPaintInfo &rInf ) const
bDraw = !rInf.GetOpt().IsGraphic();
if( !nId )
{
- SetId( sal_IntPtr( rInf.GetTextFrm() ) );
- rInf.GetTextFrm()->SetAnimation();
+ SetId( sal_IntPtr( rInf.GetTextFrame() ) );
+ rInf.GetTextFrame()->SetAnimation();
}
if( aTmp.IsOver( rInf.GetPaintRect() ) && !bDraw )
{
@@ -947,7 +947,7 @@ void SwGrfNumPortion::Paint( const SwTextPaintInfo &rInf ) const
Graphic* pGraph = const_cast<Graphic*>(pBrush->GetGraphic());
if (pGraph)
pGraph->StopAnimation(nullptr,nId);
- rInf.GetTextFrm()->getRootFrm()->GetCurrShell()->InvalidateWindows( aTmp );
+ rInf.GetTextFrame()->getRootFrame()->GetCurrShell()->InvalidateWindows( aTmp );
}
else if ( pViewShell &&
@@ -978,17 +978,17 @@ void SwGrfNumPortion::Paint( const SwTextPaintInfo &rInf ) const
}
SwRect aRepaint( rInf.GetPaintRect() );
- const SwTextFrm& rFrm = *rInf.GetTextFrm();
- if( rFrm.IsVertical() )
+ const SwTextFrame& rFrame = *rInf.GetTextFrame();
+ if( rFrame.IsVertical() )
{
- rFrm.SwitchHorizontalToVertical( aTmp );
- rFrm.SwitchHorizontalToVertical( aRepaint );
+ rFrame.SwitchHorizontalToVertical( aTmp );
+ rFrame.SwitchHorizontalToVertical( aRepaint );
}
- if( rFrm.IsRightToLeft() )
+ if( rFrame.IsRightToLeft() )
{
- rFrm.SwitchLTRtoRTL( aTmp );
- rFrm.SwitchLTRtoRTL( aRepaint );
+ rFrame.SwitchLTRtoRTL( aTmp );
+ rFrame.SwitchLTRtoRTL( aRepaint );
}
if( bDraw && aTmp.HasArea() )
@@ -1034,9 +1034,9 @@ void SwGrfNumPortion::SetBase( long nLnAscent, long nLnDescent,
}
}
-void SwTextFrm::StopAnimation( OutputDevice* pOut )
+void SwTextFrame::StopAnimation( OutputDevice* pOut )
{
- OSL_ENSURE( HasAnimation(), "SwTextFrm::StopAnimation: Which Animation?" );
+ OSL_ENSURE( HasAnimation(), "SwTextFrame::StopAnimation: Which Animation?" );
if( HasPara() )
{
SwLineLayout *pLine = GetPara();
@@ -1178,7 +1178,7 @@ bool SwCombinedPortion::Format( SwTextFormatInfo &rInf )
}
const sal_Int32 nTop = ( nCount + 1 ) / 2; // the first character of the second line
- SwViewShell *pSh = rInf.GetTextFrm()->getRootFrm()->GetCurrShell();
+ SwViewShell *pSh = rInf.GetTextFrame()->getRootFrame()->GetCurrShell();
SwFont aTmpFont( *rInf.GetFont() );
SwFontSave aFontSave( rInf, &aTmpFont );
nProportion = 55;
@@ -577,7 +577,7 @@ bool SwNumberPortion::Format( SwTextFormatInfo &rInf )
nDiff = nFixWidth + nMinDist;
// Numbering evades the Fly, no nDiff in the second round
- // Tricky special case: FlyFrm is in an Area we're just about to
+ // Tricky special case: FlyFrame is in an Area we're just about to
// acquire
// The NumberPortion is marked as hidden
@@ -858,7 +858,7 @@ bool SwGrfNumPortion::Format( SwTextFormatInfo &rInf )
nDiff = nFixWidth + nMinDist;
// Numbering evades Fly, no nDiff in the second round
- // Tricky special case: FlyFrm is in the Area we were just
+ // Tricky special case: FlyFrame is in the Area we were just
// about to get a hold of.
// The NumberPortion is marked as hidden